Class: Cucumber::Core::Events::Envelope
- Defined in:
- lib/cucumber/core/events/envelope.rb
Instance Attribute Summary collapse
-
#envelope ⇒ Object
readonly
Returns the value of attribute envelope.
Class Method Summary collapse
-
.event_id ⇒ Object
The underscored name of the class to be used as the key in an event registry @return [Symbol].
Instance Method Summary collapse
-
#initialize(envelope) ⇒ Envelope
constructor
A new instance of Envelope.
Methods inherited from Base
Constructor Details
#initialize(envelope) ⇒ Envelope
Returns a new instance of Envelope.
17 18 19 20 |
# File 'lib/cucumber/core/events/envelope.rb', line 17 def initialize(envelope) @envelope = envelope super() end |
Instance Attribute Details
#envelope ⇒ Object (readonly)
Returns the value of attribute envelope.
9 10 11 |
# File 'lib/cucumber/core/events/envelope.rb', line 9 def envelope @envelope end |
Class Method Details
.event_id ⇒ Object
The underscored name of the class to be used as the key in an event registry
@return [Symbol]
13 14 15 |
# File 'lib/cucumber/core/events/envelope.rb', line 13 def self.event_id :envelope end |