Class: Cucumber::Core::Test::Result::Flaky

Inherits:
Object
  • Object
show all
Defined in:
lib/cucumber/core/test/result/flaky.rb

Overview

Flaky is not used directly as an execution result, but is used as a reporting result type for test cases that fails and the passes on retry, therefore only the class method self.ok? is needed.

Class Method Summary collapse

Class Method Details

.ok?Boolean

Returns:

  • (Boolean)


14
15
16
# File 'lib/cucumber/core/test/result/flaky.rb', line 14

def self.ok?
  false
end