Module: Cucumber::Core::Test::Result::BooleanMethods

Included in:
Ambiguous, Failed, Passed, Pending, Skipped, Undefined, Unknown
Defined in:
lib/cucumber/core/test/result/boolean_methods.rb

Overview

Simple module that when included generates all the boolean methods for each category of result The single exception to this is the class method ‘self.ok?` which is defined for each result individually

Constant Summary collapse

TYPES =
%i[failed ambiguous flaky undefined pending skipped passed unknown].freeze

Instance Method Summary collapse

Instance Method Details

#ok?Boolean

Returns:

  • (Boolean)


21
22
23
# File 'lib/cucumber/core/test/result/boolean_methods.rb', line 21

def ok?
  self.class.ok?
end